@@ -27,12 +27,11 @@
 
 #include "mpriscontroller.h"
 
-#include <qqmlinfo.h>
-
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 
 #include <QtCore/QSignalMapper>
+#include <QDebug>
 
 static const QString mprisNameSpace = QStringLiteral("org.mpris.MediaPlayer2.*");
 static const QString dBusService = QStringLiteral("org.freedesktop.DBus");
@@ -40,16 +39,25 @@ static const QString dBusObjectPath = QStringLiteral("/org/freedesktop/DBus");
 static const QString dBusInterface = QStringLiteral("org.freedesktop.DBus");
 static const QString dBusNameOwnerChangedSignal = QStringLiteral("NameOwnerChanged");
 
+static inline QDBusConnection getDBusConnection()
+{
+#ifdef USE_SYSTEM_DBUS
+    return QDBusConnection::systemBus();
+#else
+    return QDBusConnection::sessionBus();
+#endif
+}
+
 
 MprisManager::MprisManager(QObject *parent)
     : QObject(parent)
     , m_singleService(false)
     , m_playbackStatusMapper(new QSignalMapper(this))
 {
-    QDBusConnection connection = QDBusConnection::sessionBus();
+    QDBusConnection connection = getDBusConnection();
 
     if (!connection.isConnected()) {
-        qmlInfo(this) << "Failed attempting to connect to DBus";
+        qWarning() << "Mpris: Failed attempting to connect to DBus";
         return;
     }
 
@@ -151,7 +159,7 @@ void MprisManager::setSingleService(bool single)
     }
 
     m_singleService = single;
-    emit singleServiceChanged();
+    Q_EMIT singleServiceChanged();
 }
 
 QString MprisManager::currentService() const
@@ -168,13 +176,13 @@ void MprisManager::setCurrentService(const QString &service)
     QRegExp rx(mprisNameSpace);
     rx.setPatternSyntax(QRegExp::Wildcard);
     if (!rx.exactMatch(service)) {
-        qmlInfo(this) << service << "is not a proper Mpris2 service";
+        qWarning() << "Mpris:" << service << "is not a proper Mpris2 service";
         return;
     }
 
     QSharedPointer<MprisController> controller = availableController(service);
     if (controller.isNull()) {
-        controller = QSharedPointer<MprisController>(new MprisController(service, QDBusConnection::sessionBus(), this));
+        controller = QSharedPointer<MprisController>(new MprisController(service, getDBusConnection(), this));
     } else {
         m_availableControllers.move(m_availableControllers.indexOf(controller), 0);
     }
@@ -402,7 +410,7 @@ void MprisManager::onServiceAppeared(const QString &service)
         if (!m_currentController.isNull() && service == m_currentController->service()) {
             controller = m_currentController;
         } else {
-            controller = QSharedPointer<MprisController>(new MprisController(service, QDBusConnection::sessionBus(), this));
+            controller = QSharedPointer<MprisController>(new MprisController(service, getDBusConnection(), this));
         }
 
         connect(controller.data(), SIGNAL(playbackStatusChanged()), m_playbackStatusMapper, SLOT(map()));
@@ -416,7 +424,7 @@ void MprisManager::onServiceAppeared(const QString &service)
 
     if (controller == m_currentController) {
         m_availableControllers.prepend(controller);
-        emit availableServicesChanged();
+        Q_EMIT availableServicesChanged();
         return;
     }
 
@@ -431,7 +439,7 @@ void MprisManager::onServiceAppeared(const QString &service)
         }
     }
 
-    emit availableServicesChanged();
+    Q_EMIT availableServicesChanged();
 }
 
 void MprisManager::onServiceVanished(const QString &service)
@@ -445,7 +453,7 @@ void MprisManager::onServiceVanished(const QString &service)
 
     if (!m_currentController.isNull() && service == m_currentController->service()) {
         if (m_singleService) {
-            emit availableServicesChanged();
+            Q_EMIT availableServicesChanged();
             return;
         }
 
@@ -456,7 +464,7 @@ void MprisManager::onServiceVanished(const QString &service)
         }
     }
 
-    emit availableServicesChanged();
+    Q_EMIT availableServicesChanged();
 }
 
 void MprisManager::onAvailableControllerPlaybackStatusChanged(const QString &service)
@@ -583,7 +591,7 @@ void MprisManager::setCurrentController(QSharedPointer<MprisController> controll
         }
     }
 
-    emit currentServiceChanged();
+    Q_EMIT currentServiceChanged();
 }
 
 bool MprisManager::checkController(const char *callerName) const
